@@ -75,6 +75,17 @@ describe 'oslo::db' do
       end
     end
 
+    context 'with config management disabled' do
+      let :params do
+        { :manage_config => false }
+      end
+
+      it 'does not manage config options' do
+        is_expected.to_not contain_keystone_config('custom_group/backend')
+        is_expected.to_not contain_keystone_config('custom_group/conection')
+      end
+    end
+
     context 'with pymysql connection' do
       let :params do
         { :connection => 'mysql+pymysql://db:db@localhost/db' }
@@ -89,9 +100,8 @@ describe 'oslo::db' do
         { :connection => 'postgresql://db:db@localhost/db', }
       end
 
-      it 'install the proper backend package' do
-        is_expected.to contain_package('python-psycopg2').with(:ensure => 'present')
-      end
+      it { is_expected.to contain_keystone_config('database/connection').with_value('postgresql://db:db@localhost/db').with_secret(true) }
+      it { is_expected.to contain_class('postgresql::lib::python') }
 
       context 'with backend package management disabled' do
         before do
@@ -101,7 +111,7 @@ describe 'oslo::db' do
         end
 
         it 'does not install backend package' do
-          is_expected.not_to contain_package('python-psycopg2')
+          is_expected.not_to contain_class('postgresql::lib::python')
         end
       end
     end
@@ -112,6 +122,7 @@ describe 'oslo::db' do
       end
 
       it { is_expected.to contain_keystone_config('database/connection').with_value('postgresql+psycopg2://db:db@localhost/db').with_secret(true) }
+      it { is_expected.to contain_class('postgresql::lib::python') }
     end
 
     context 'with incorrect database_connection string' do
@@ -139,7 +150,7 @@ describe 'oslo::db' do
 
       it 'install the proper backend package' do
         is_expected.to contain_package(platform_params[:pymysql_package_name]).with(
-          :ensure => 'present',
+          :ensure => 'installed',
           :name   => platform_params[:pymysql_package_name],
           :tag    => 'openstack'
         )
@@ -165,7 +176,7 @@ describe 'oslo::db' do
 
       it 'install the proper backend package' do
         is_expected.to contain_package(platform_params[:pysqlite2_package_name]).with(
-          :ensure => 'present',
+          :ensure => 'installed',
           :name   => platform_params[:pysqlite2_package_name],
           :tag    => 'openstack'
         )
